.str{color:#00946f}
.kwd{color:#008}
.com{color:#800}
.typ{color:#606}
.lit{color:#066}
.pun{color:#660}
.pln{color:#000}
.tag{color:#008}
.atn{color:#606}
.atv{color:#080}
.dec{color:#606}
pre.prettyprint{padding:5px;border:3px solid #cec793;background-color:#fafaf3;overflow:scroll; z-index:9999999; position:relative; }
pre.prettyprint:hover {padding:5px;border:3px solid #cec793;background-color:#fafaf3;overflow:visible; width:800px; z-index:9999999;position:relative; }
pre{padding:5px;border:3px solid #cec793;background-color:#fafaf3;overflow:scroll; z-index:9999999; position:relative; }
pre:hover {padding:5px;border:3px solid #cec793;background-color:#fafaf3;overflow:visible; width:800px; z-index:9999999;position:relative; }
.highlight {margin-bottom: 10px;}
@media print{
	.str{color:#060}
.kwd{color:#006;font-weight:bold}
.com{color:#600;font-style:italic}
.typ{color:#404;font-weight:bold}
.lit{color:#044}
.pun{color:#440}
.pln{color:#000}
.tag{color:#006;font-weight:bold}
.atn{color:#404}
.atv{color:#060}}
