{% extends 'blogango/base.html' %}

{% block breadcrumbs %}
	<li>Blog</li>
{% endblock %}

{% block content%}

<!--BLOG POST STARTS-->
{% for entry in entries %}
    {% include 'blogango/entry_snippets.html' %}
{% empty %}
    <div class="leftblock"> 
        <h1>No posts in blog</h1> 
        <div class="postcontent">
            <p>
              <br/>You don't have any entries in your blog, 
              you can post to your blog from site admin.
            </p>
        </div>
    </div>
{% endfor %}  
<!--BLOG POST ENDS-->
<div class="clear"></div>
{% if page_.has_next or page_.has_previous %}
<div class="pagination"> 
    <div class="moreinfo">
        {% if page_.has_next %}
            <a href='{% url blogango_page page_.next_page_number %}'>&laquo; Previous Entries</a>
        {% endif %}
        
        {% if page_.has_previous %}
            <span class='right'><a href='{% url blogango_page page_.previous_page_number %}'>Next Entries &raquo;</a></span>
        {% endif %}
    </div> 
</div>
{% endif %}

{% endblock %}
