{% extends "blogango/base.html" %}

{% block title %} 
- Archives for {{ month|date:"F" }} {{ month|date:"Y" }}
{% endblock %}

{% block breadcrumbs %}
    <li><a href="{% url blogango_index %}" rel="nofollow">Blog</a></li>
    <li>{{ month|date:'N Y' }}</li>
{% endblock %}

{% block content %}

{% for entry in object_list %}
    {% include 'blogango/entry_snippets.html' %}
{% endfor %}

{% endblock %}

