{% extends "blogango/base.html" %}

{% block title %}
{{block.super}} - Install
{% endblock %}

{% block content %}
<div class="leftblock">
    <h1>Blog not created </h1> 

<div class="postcontent">
    <p>Create a blog in '/admin/'</p>
</div>

{% comment %}
<form action="." method="post">
    <table>
    {{install_form}}
    </table>
    <input name="install" type="submit" value="Install Blog" class="button"/>
</form>
{% endcomment %}

</div>

{% endblock %}
