{% extends 'blogango/base.html' %}

{% block title %}
    {{block.super}} - Tagged with {{ tag.name }}
{% endblock %}

{% block breadcrumbs %}
    <li><a href="{% url blogango_index %}" rel="nofollow">Blog</a></li>
    <li>Category: {{ tag.name }}</li>
{% endblock %}

{% block content %}
	{% for entry in entries %}
	    {% include 'blogango/entry_snippets.html' %}
	{% empty %}
	    <div class="leftblock"> 
	        <h1>No entries with this tag</h1> 
	        <div class="postcontent">
	            <p>
	              <br/>
	              No entries tagged {{ tag.name }}
	            </p>
	        </div>
	    </div>
	{% endfor %}
    <div class="clear"></div>
    {% if page_.has_next or page_.has_previous %}
    <div class="pagination"> 
        <div class="moreinfo">
            {% if page_.has_next %}
                <a href='{% url blogango_tag_details_page tag.slug page_.next_page_number %}'>&laquo; Previous Entries</a>
            {% endif %}
            
            {% if page_.has_previous %}
                <span class='right'><a href='{% url blogango_tag_details_page tag.slug page_.previous_page_number %}'>Next Entries &raquo;</a></span>
            {% endif %}
        </div> 
    </div>
    {% endif %}
{% endblock %}
